# Gaussian Inflection Spline Interpolation Continuum
### GISIC
### Author: Devin Whitten
### Date: February 18, 2018

This package is performs normalization of astronomical spectra based on a continuum identification routine.
GISIC performs a gaussian smoothing of the flux array, and identifies molecular bands based on a numerical gradient. Continuum points are then interpolated with a cubic spline.

![Example Spectrum](https://github.com/DevinWhitten/GISIC/blob/master/plots/T4500g0.50z-2.50c%2B2.00.png)



